/*
Program obsługi Aeroduino
Pierwszy przełącznik S1 decyduje o trybie pracy:  
digitalRead(5)=1:  wszystkie włączone
digitalRead(5)=0:  włączane po kolei tam i z powrotem (wówczas położenie potencjometru 
(analogRead(A0)) decyduje o prędkości przełączania).
Drugi przełącznik S2 (digitalRead(3)) w tej chwili nie jest wykorzystywany.
*/

#include <Wire.h>
#include <Adafruit_PWMServoDriver.h>

Adafruit_PWMServoDriver pwm = Adafruit_PWMServoDriver();    //Utworzenie obiektu pwm
//Składnia:
//setPWM(channel, on, off); Channel scope:0-15,   On/off scope: 0-4095
//Na przykład:
//pwm.setPWM(channel, 4096, 0);   //Całkowite włączenie kanału
//pwm.setPWM(channel, 0, 4096);   //Całkowite wyłączenie kanału

float CzasCzekania()      //Ustaw czas czekania
{
  double Wartosc = (double) analogRead(A0);
  double Czas = 3 * Wartosc + 50;  //Formuła dobrana doświadczalnie
  //Serial.println (Czas);   //W razie potrzeby kontrolne wysłanie wartości czasu do komputera
  return Czas;
}


void Wlaczanie_Prawo_Lewo()   //Dmuchawy włączają się kolejno od lewej do prawej i z powrotem
{
  for (uint8_t channel = 0; channel < 12; channel++)    //Włączanie w kierunku na "prawo"
  {    
    pwm.setPWM((channel) % 14, 4096, 0);        //Pełne włączenie channel
    pwm.setPWM((channel + 1) % 14, 4096, 0);    //Pełne włączenie channel+1
    pwm.setPWM((channel + 2) % 14, 4096, 0);    //Pełne włączenie channel+2
    delay(CzasCzekania());
    pwm.setPWM((channel) % 14, 0, 4096);        //Wyłączenie channel
    delay(CzasCzekania());
  }

  for (int channel = 12; channel > 0; channel--)     //Włączanie w kierunku na "lewo"
  {    
    pwm.setPWM(channel-1, 4096, 0);   //Pełne włączenie channel-1
    pwm.setPWM(channel, 4096, 0);     //Pełne włączenie channel
    delay(CzasCzekania());
    pwm.setPWM(channel + 1, 0, 4096); //Wyłączenie channel+1
    delay(CzasCzekania()); 
  }
}


void Wlaczenie_Wszystkich()     //Włączenie wszystkich dmuchaw
{
  for (uint8_t channel = 0; channel < 14; channel++)
  {
    pwm.setPWM((channel) % 14, 4096, 0);    //Pełne włączenie channel
    delay(200);   //Odczekanie aby nagle nie obciążyć zasilania
  }
}


void setup()
{
  Serial.begin(9600);
  //pinMode(2, INPUT);
  pinMode(3, INPUT);
  //pinMode(4, INPUT);
  pinMode(5, INPUT);
  pwm.begin();
  pwm.setPWMFreq(1000);     // Scope: 40-1000Hz
  Wire.setClock(100000);    // 100kHz I2C clock frequency
  for (uint8_t i = 0; i <= 13; i++)  pwm.setPWM(i, 0, 4096);    //Początkowe wyłączenie wszystkich kanałów
}


void loop()
{
 if(digitalRead(5)) Wlaczenie_Wszystkich();
 else Wlaczanie_Prawo_Lewo();
}

